pub fn decode_dispute_event(
event: &ContractEvent,
) -> Option<Result<(AccountAddress, Option<u64>)>>Expand description
Decode either dispute event, None for any other key. Both versions are
recognised in one place so a third consumer cannot support one and silently
drop the other.